Learn R Programming

pense (version 2.5.2)

.mopt_efficiency_const: Get the constant for the desired efficiency of the M-estimate of location using the optimal \(\rho\) function

Description

Get the constant for the desired efficiency of the M-estimate of location using the optimal \(\rho\) function

Usage

.mopt_efficiency_const(eff, eps = sqrt(.Machine$double.eps))

Value

tuning constant for desired efficiency

Arguments

eff

desired efficiency (between 0 and 1)

eps

numerical tolerance for equality comparisons