Learn R Programming

pense (version 2.5.2)

change_cv_measure: Change the Cross-Validation Measure

Description

For cross-validated fits using the RIS-CV strategy, the measure of prediction accuracy can be adjusted post-hoc.

Usage

change_cv_measure(
  x,
  measure = c("wrmspe", "wmape", "tau_size", "wrmspe_cv", "wmape_cv"),
  max_solutions = Inf
)

Value

a pense.cvfit object using the updated measure of prediction accuracy

Arguments

x

fitted (adaptive) PENSE or M-estimator

measure

the measure to use for prediction accuracy

max_solutions

consider only this many of the best solutions. If missing, all solutions are considered.

See Also

Other functions to compute robust estimates with CV: pense_cv(), regmest_cv()