| mlocscale | R Documentation |
Simultaneous estimation of the location and scale by means of M-estimates.
mlocscale(
x,
bdp = 0.25,
eff = 0.9,
scale_cc,
location_rho,
location_cc,
opts = mscale_algorithm_options()
)
x |
numeric values. Missing values are verbosely ignored. |
bdp |
desired breakdown point (between 0 and 0.5). |
eff |
desired efficiency of the location estimate (between 0.1 and 0.99). |
scale_cc |
tuning constant for the |
location_rho |
|
location_cc |
tuning constant for the location |
opts |
a list of options for the M-scale estimating equations,
See |
a vector with 2 elements, the M-estimate of location and the M-scale estimate.
Other functions to compute robust estimates of location and scale:
mloc(),
mscale(),
tau_size()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.