For cross-validated fits using the RIS-CV strategy, the measure of prediction accuracy can be adjusted post-hoc.
change_cv_measure(
x,
measure = c("wrmspe", "wmape", "tau_size", "wrmspe_cv", "wmape_cv"),
max_solutions = Inf
)a pense.cvfit object using the updated measure of prediction accuracy
fitted (adaptive) PENSE or M-estimator
the measure to use for prediction accuracy
consider only this many of the best solutions. If missing, all solutions are considered.
Other functions to compute robust estimates with CV:
pense_cv(),
regmest_cv()