| mloc | R Documentation |
Compute the M-estimate of location using an auxiliary estimate of the scale.
mloc(x, scale, rho = "bisquare", eff = 0.9, cc, max_it = 200, eps = 1e-08)
x |
numeric values. Missing values are verbosely ignored. |
scale |
scale of the |
rho |
the |
eff |
desired efficiency under the Normal model. |
cc |
value of the tuning constant for the chosen |
max_it |
maximum number of iterations. |
eps |
numerical tolerance to check for convergence. |
a single numeric value, the M-estimate of location.
Other functions to compute robust estimates of location and scale:
mlocscale(),
mscale(),
tau_size()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.